	{keymap_GreekMonotonic, "gr"},
	{keymap_Cyrillic, "cy"},
	{keymap_Hebrew, "he"},
	{keymap_ArabicKeyboard, "ar"},
	{keymap_Pinyin, "py"},
	{keymap_Cangjie, "cj"},
	{keymap_WuBi, "wu"},
	{keymap_4Corner, "4c"},
	{keymap_Boshiamy, "bo"},
	{keymap_Radical_Stroke, "rs"},
	{keymap_Hiragana, "hi"},
	{keymap_Katakana, "ka"},
	{keymap_TUT_roma, "tu"},
	{keymap_HANGUL, "hg"},
	{keymap_HANJA, "hj"},
	{keymap_VNI, "vi"},
	{keymap_VIQR, "vq"},
	{keymap_Thai, "th"},
